==> element-web-1.11.92.tar.gz: element-web-1.11.92/test/unit-tests/components/views/settings/encryption/ResetIdentityPanel-test.tsx <==
/*
 * Copyright 2025 New Vector Ltd.
 *
 * SPDX-License-Identifier: AGPL-3.0-only OR GPL-3.0-only OR LicenseRef-Element-Commercial
 * Please see LICENSE files in the repository root for full details.
 */

import React from "react";
import { MatrixClient } from "matrix-js-sdk/src/matrix";
import { render, screen } from "jest-matrix-react";
import userEvent from "@testing-library/user-event";

import { ResetIdentityPanel } from "../../../../../../src/components/views/settings/encryption/ResetIdentityPanel";
import { createTestClient, withClientContextRenderOptions } from "../../../../../test-utils";

describe("<ResetIdentityPanel />", () => {
    let matrixClient: MatrixClient;

    beforeEach(() => {
        matrixClient = createTestClient();
    });

    it("should reset the encryption when the continue button is clicked", async () => {
        const user = userEvent.setup();

        const onFinish = jest.fn();
        const { asFragment } = render(
            <ResetIdentityPanel variant="compromised" onFinish={onFinish} onCancelClick={jest.fn()} />,
            withClientContextRenderOptions(matrixClient),
        );
        expect(asFragment()).toMatchSnapshot();

        await user.click(screen.getByRole("button", { name: "Continue" }));
        expect(matrixClient.getCrypto()!.resetEncryption).toHaveBeenCalled();
        expect(onFinish).toHaveBeenCalled();
    });

    it("should display the 'forgot recovery key' variant correctly", async () => {
        const onFinish = jest.fn();
        const { asFragment } = render(
            <ResetIdentityPanel variant="forgot" onFinish={onFinish} onCancelClick={jest.fn()} />,
            withClientContextRenderOptions(matrixClient),
        );
        expect(asFragment()).toMatchSnapshot();
    });
});

==> element-web-1.11.93.tar.gz: element-web-1.11.93/test/unit-tests/components/views/settings/encryption/ResetIdentityPanel-test.tsx <==
/*
 * Copyright 2025 New Vector Ltd.
 *
 * SPDX-License-Identifier: AGPL-3.0-only OR GPL-3.0-only OR LicenseRef-Element-Commercial
 * Please see LICENSE files in the repository root for full details.
 */

import React from "react";
import { type MatrixClient } from "matrix-js-sdk/src/matrix";
import { render, screen } from "jest-matrix-react";
import userEvent from "@testing-library/user-event";

import { ResetIdentityPanel } from "../../../../../../src/components/views/settings/encryption/ResetIdentityPanel";
import { createTestClient, withClientContextRenderOptions } from "../../../../../test-utils";

describe("<ResetIdentityPanel />", () => {
    let matrixClient: MatrixClient;

    beforeEach(() => {
        matrixClient = createTestClient();
    });

    it("should reset the encryption when the continue button is clicked", async () => {
        const user = userEvent.setup();

        const onFinish = jest.fn();
        const { asFragment } = render(
            <ResetIdentityPanel variant="compromised" onFinish={onFinish} onCancelClick={jest.fn()} />,
            withClientContextRenderOptions(matrixClient),
        );
        expect(asFragment()).toMatchSnapshot();

        await user.click(screen.getByRole("button", { name: "Continue" }));
        expect(matrixClient.getCrypto()!.resetEncryption).toHaveBeenCalled();
        expect(onFinish).toHaveBeenCalled();
    });

    it("should display the 'forgot recovery key' variant correctly", async () => {
        const onFinish = jest.fn();
        const { asFragment } = render(
            <ResetIdentityPanel variant="forgot" onFinish={onFinish} onCancelClick={jest.fn()} />,
            withClientContextRenderOptions(matrixClient),
        );
        expect(asFragment()).toMatchSnapshot();
    });
});
